==> phpMinAdmin-1.7.0.zip: phpMinAdmin-1.7.0/lang/fr.inc.php <==
<?php
$translations = array(
	'Login' => 'Authentification',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Aurevoir!',
	'Invalid credentials.' => 'Authentification échoué',
	'Server' => 'Serveur',
	'Username' => 'Utilisateur',
	'Password' => 'Mot de passe',
	'Select database' => 'Selectionner la base de donnée',
	'Invalid database.' => 'Base de donnée invalide',
	'Create new database' => 'Créer une base de donnée',
	'Table has been dropped.' => 'Table effacée',
	'Table has been altered.' => 'Table modifiée',
	'Table has been created.' => 'Table créée.',
	'Alter table' => 'Modifier la table',
	'Create table' => 'Crear tabla',
	'Table name' => 'Nom de la table',
	'engine' => 'moteur',
	'collation' => 'collation',
	'Column name' => 'Nombre de colonne',
	'Type' => 'Type',
	'Length' => 'Longeur',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto increment',
	'Options' => 'Opions',
	'Save' => 'Sauvegarder',
	'Drop' => 'Effacer',
	'Database has been dropped.' => 'Base de données effacée.',
	'Database has been created.' => 'Base de données créée.',
	'Database has been renamed.' => 'Base de données renommée.',
	'Database has been altered.' => 'Base de données modifiée.',
	'Alter database' => 'Modifier la base de données',
	'Create database' => 'Créer une base de données',
	'SQL command' => 'Requête SQL',
	'Dump' => 'Exporter',
	'Logout' => 'Déconnexion',
	'database' => 'base de données',
	'Use' => 'Utiliser',
	'No tables.' => 'Aucunes tables.',
	'select' => 'select',
	'Create new table' => 'Créer un table',
	'Item has been deleted.' => 'Élément supprimé.',
	'Item has been updated.' => 'Élément modifié.',
	'Item has been inserted.' => 'Élément inseré.',
	'Edit' => 'Modifier',
	'Insert' => 'Insérer',
	'Save and insert next' => 'Sauvegarder et insérer le prochain',
	'Delete' => 'Effacer',
	'Database' => 'Base de données',
	'Routines' => 'Routines',
	'Indexes has been altered.' => 'Index modifiés.',
	'Indexes' => 'Index',
	'Alter indexes' => 'Modifier les index',
	'Add next' => 'Ajouter le prochain',
	'Language' => 'Langues',
	'Select' => 'Select',
	'New item' => 'Nouvel élément',
	'Search' => 'Rechercher',
	'Sort' => 'Ordonner',
	'DESC' => 'DESC',
	'Limit' => 'Limit',
	'No rows.' => 'Aucun résultat',
	'Action' => 'Action',
	'edit' => 'modifier',
	'Page' => 'Page',
	'Query executed OK, %d row(s) affected.' => array('Requête exécutée, %d ligne affecteé.', 'Requête exécutée, %d lignes affectées.'),
	'Error in query' => 'Erreur dans la requête',
	'Execute' => 'Exécuter',
	'Table' => 'Table',
	'Foreign keys' => 'Clé externe',
	'Triggers' => 'Triggers',
	'View' => 'Vue',
	'Unable to select the table' => 'Impossible de sélectionner la table',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF invalide. Veuillez réenvoyer le formulaire.',
	'Comment' => 'Commentaire',
	'Default values has been set.' => 'Valeur par défaut établie .',
	'Default values' => 'Valeurs par défaut',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Voir les commentaires sur les colonnes',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Aucune commande à exécuter.',
	'Unable to upload a file.' => 'Impossible d\'importer le fichier.',
	'File upload' => 'Importer un fichier',
	'File uploads are disabled.' => 'Import de fichier désactivé.',
	'Routine has been called, %d row(s) affected.' => array('Routine exécutée, %d ligne modifiée.', 'Routine exécutée, %d lignes modifiées.'),
	'Call' => 'Appeler',
	'No MySQL extension' => 'Extension MySQL introuvable',
	'None of supported PHP extensions (%s) are available.' => 'Aucune des extensions PHP supportées (%s) n\'est disponible.',
	'Sessions must be enabled.' => 'Veuillez activer les sessions.',
	'Session expired, please login again.' => 'Session expiré, veuillez vous enregistrer à nouveau.',
	'Text length' => 'Longueur du texte',
	'Syntax highlighting' => 'Coloration syntaxique',
	'Foreign key has been dropped.' => 'Clé externe effacée.',
	'Foreign key has been altered.' => 'Clé externe modifiée.',
	'Foreign key has been created.' => 'Clé externe créée.',
	'Foreign key' => 'Clé externe',
	'Target table' => 'Table visée',
	'Change' => 'Modifier',
	'Source' => 'Source',
	'Target' => 'Cible',
	'Add column' => 'Ajouter une colonne',
	'Alter' => 'Modifier',
	'Add foreign key' => 'Ajouter une clé externe',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Type d\'index',
	'Column (length)' => 'Colonne (longueur)',
	'View has been dropped.' => 'Vue effacée.',
	'View has been altered.' => 'Vue modifiée.',
	'View has been created.' => 'Vue créée.',
	'Alter view' => 'Modifier une vue',
	'Create view' => 'Créer une vue',
	'Name' => 'Nom',
	'Process list' => 'Liste de processus',
	'%d process(es) has been killed.' => array('%d processus arrêté.', '%d processus arrêtés.'),
	'Kill' => 'Arrêter',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Nom du Paramêtre',
	'Database schema' => 'Schéma de la base de données',
	'Create procedure' => 'Créer une procédure',
	'Create function' => 'Créer une fonction',
	'Routine has been dropped.' => 'Procédure éliminée.',
	'Routine has been altered.' => 'Procédure modifiée.',
	'Routine has been created.' => 'Procédure créée.',
	'Alter function' => 'Modifié la fonction',
	'Alter procedure' => 'Modifié la procédure',
	'Return type' => 'Type de retour',
	'Add trigger' => 'Ajouter un trigger',
	'Trigger has been dropped.' => 'Trigger éliminé.',
	'Trigger has been altered.' => 'Trigger modifié.',
	'Trigger has been created.' => 'Trigger créé.',
	'Alter trigger' => 'Modifier un trigger',
	'Create trigger' => 'Ajouter un trigger',
	'Time' => 'Temps',
	'Event' => 'Évènement',
	'%d row(s)' => array('%d ligne', '%d lignes'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Effacer',
	'Are you sure?' => 'Êtes-vous certain?',
	'Privileges' => 'Privilège',
	'Create user' => 'Créer un utilisateur',
	'User has been dropped.' => 'Utilisateur éffacé.',
	'User has been altered.' => 'Utilisateur modifié.',
	'User has been created.' => 'Utilisateur créé.',
	'Hashed' => 'Haché',
	'Column' => 'Colonne',
	'Routine' => 'Routine',
	'Grant' => 'Grant',
	'Revoke' => 'Rovoke',
	'Error during deleting' => 'Erreur durant la suppression',
	'%d item(s) have been deleted.' => array('%d élément effacé.', '%d éléments éffacés.'),
	'all' => 'tout',
	'Delete selected' => 'Effacer les éléments selectionnés',
	'MySQL version: %s through PHP extension %s' => 'Version de MySQL: %s utilisant l\'extension %s',
	'around %d row(s)' => array('autour de la ligne %d', 'autour des lignes %d'),
	'Logged as: %s' => 'Authentifié en tant que %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'Donnée POST trop grande . Réduire la taille des données ou modifier le "post_max_size" dans la configuration de PHP.',
	'Move up' => 'Déplacer vers le haut',
	'Move down' => 'Déplacer vers le bas',
	'Export' => 'Exporter',
	'skip' => 'sauter',
	'Tables' => 'Tables',
	'Structure' => 'Structure',
	'Data' => 'Donnée',
	'Output' => 'Sortie',
	'open' => 'ouvrir',
	'save' => 'sauvegarder',
	'Format' => 'Formatter',
	'SQL' => 'SQL',
	'CSV' => 'CVS',
	'Functions' => 'Fonctions',
	'Aggregation' => 'Aggregation',
	'Truncate result' => 'Tronquer le résultat',
	'Export selected' => 'Exporter la sélection',
	'Export result' => 'Exporter le résultat',
);

==> phpMinAdmin-1.9.1.zip: phpMinAdmin-1.9.1/lang/fr.inc.php <==
<?php
$translations = array(
	'Login' => 'Authentification',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Aurevoir!',
	'Invalid credentials.' => 'Authentification échoué',
	'Server' => 'Serveur',
	'Username' => 'Utilisateur',
	'Password' => 'Mot de passe',
	'Select database' => 'Selectionner la base de donnée',
	'Invalid database.' => 'Base de donnée invalide',
	'Create new database' => 'Créer une base de donnée',
	'Table has been dropped.' => 'Table effacée',
	'Table has been altered.' => 'Table modifiée',
	'Table has been created.' => 'Table créée.',
	'Alter table' => 'Modifier la table',
	'Create table' => 'Créer une table',
	'Table name' => 'Nom de la table',
	'engine' => 'moteur',
	'collation' => 'collation',
	'Column name' => 'Nombre de colonne',
	'Type' => 'Type',
	'Length' => 'Longeur',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto increment',
	'Options' => 'Opions',
	'Save' => 'Sauvegarder',
	'Drop' => 'Effacer',
	'Database has been dropped.' => 'Base de données effacée.',
	'Database has been created.' => 'Base de données créée.',
	'Database has been renamed.' => 'Base de données renommée.',
	'Database has been altered.' => 'Base de données modifiée.',
	'Alter database' => 'Modifier la base de données',
	'Create database' => 'Créer une base de données',
	'SQL command' => 'Requête SQL',
	'Dump' => 'Exporter',
	'Logout' => 'Déconnexion',
	'database' => 'base de données',
	'Use' => 'Utiliser',
	'No tables.' => 'Aucunes tables.',
	'select' => 'select',
	'Create new table' => 'Créer une table',
	'Item has been deleted.' => 'Élément supprimé.',
	'Item has been updated.' => 'Élément modifié.',
	'Item has been inserted.' => 'Élément inseré.',
	'Edit' => 'Modifier',
	'Insert' => 'Insérer',
	'Save and insert next' => 'Sauvegarder et insérer le prochain',
	'Delete' => 'Effacer',
	'Database' => 'Base de données',
	'Routines' => 'Routines',
	'Indexes has been altered.' => 'Index modifiés.',
	'Indexes' => 'Index',
	'Alter indexes' => 'Modifier les index',
	'Add next' => 'Ajouter le prochain',
	'Language' => 'Langues',
	'Select' => 'Select',
	'New item' => 'Nouvel élément',
	'Search' => 'Rechercher',
	'Sort' => 'Ordonner',
	'DESC' => 'DESC',
	'Limit' => 'Limit',
	'No rows.' => 'Aucun résultat',
	'Action' => 'Action',
	'edit' => 'modifier',
	'Page' => 'Page',
	'Query executed OK, %d row(s) affected.' => array('Requête exécutée, %d ligne affecteé.', 'Requête exécutée, %d lignes affectées.'),
	'Error in query' => 'Erreur dans la requête',
	'Execute' => 'Exécuter',
	'Table' => 'Table',
	'Foreign keys' => 'Clé externe',
	'Triggers' => 'Triggers',
	'View' => 'Vue',
	'Unable to select the table' => 'Impossible de sélectionner la table',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF invalide. Veuillez réenvoyer le formulaire.',
	'Comment' => 'Commentaire',
	'Default values has been set.' => 'Valeur par défaut établie .',
	'Default values' => 'Valeurs par défaut',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Voir les commentaires sur les colonnes',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Aucune commande à exécuter.',
	'Unable to upload a file.' => 'Impossible d\'importer le fichier.',
	'File upload' => 'Importer un fichier',
	'File uploads are disabled.' => 'Import de fichier désactivé.',
	'Routine has been called, %d row(s) affected.' => array('Routine exécutée, %d ligne modifiée.', 'Routine exécutée, %d lignes modifiées.'),
	'Call' => 'Appeler',
	'No MySQL extension' => 'Extension MySQL introuvable',
	'None of supported PHP extensions (%s) are available.' => 'Aucune des extensions PHP supportées (%s) n\'est disponible.',
	'Sessions must be enabled.' => 'Veuillez activer les sessions.',
	'Session expired, please login again.' => 'Session expiré, veuillez vous enregistrer à nouveau.',
	'Text length' => 'Longueur du texte',
	'Syntax highlighting' => 'Coloration syntaxique',
	'Foreign key has been dropped.' => 'Clé externe effacée.',
	'Foreign key has been altered.' => 'Clé externe modifiée.',
	'Foreign key has been created.' => 'Clé externe créée.',
	'Foreign key' => 'Clé externe',
	'Target table' => 'Table visée',
	'Change' => 'Modifier',
	'Source' => 'Source',
	'Target' => 'Cible',
	'Add column' => 'Ajouter une colonne',
	'Alter' => 'Modifier',
	'Add foreign key' => 'Ajouter une clé externe',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Type d\'index',
	'Column (length)' => 'Colonne (longueur)',
	'View has been dropped.' => 'Vue effacée.',
	'View has been altered.' => 'Vue modifiée.',
	'View has been created.' => 'Vue créée.',
	'Alter view' => 'Modifier une vue',
	'Create view' => 'Créer une vue',
	'Name' => 'Nom',
	'Process list' => 'Liste de processus',
	'%d process(es) has been killed.' => array('%d processus arrêté.', '%d processus arrêtés.'),
	'Kill' => 'Arrêter',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Nom du Paramêtre',
	'Database schema' => 'Schéma de la base de données',
	'Create procedure' => 'Créer une procédure',
	'Create function' => 'Créer une fonction',
	'Routine has been dropped.' => 'Procédure éliminée.',
	'Routine has been altered.' => 'Procédure modifiée.',
	'Routine has been created.' => 'Procédure créée.',
	'Alter function' => 'Modifié la fonction',
	'Alter procedure' => 'Modifié la procédure',
	'Return type' => 'Type de retour',
	'Add trigger' => 'Ajouter un trigger',
	'Trigger has been dropped.' => 'Trigger éliminé.',
	'Trigger has been altered.' => 'Trigger modifié.',
	'Trigger has been created.' => 'Trigger créé.',
	'Alter trigger' => 'Modifier un trigger',
	'Create trigger' => 'Ajouter un trigger',
	'Time' => 'Temps',
	'Event' => 'Évènement',
	'%d row(s)' => array('%d ligne', '%d lignes'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Effacer',
	'Are you sure?' => 'Êtes-vous certain?',
	'Privileges' => 'Privilège',
	'Create user' => 'Créer un utilisateur',
	'User has been dropped.' => 'Utilisateur éffacé.',
	'User has been altered.' => 'Utilisateur modifié.',
	'User has been created.' => 'Utilisateur créé.',
	'Hashed' => 'Haché',
	'Column' => 'Colonne',
	'Routine' => 'Routine',
	'Grant' => 'Grant',
	'Revoke' => 'Rovoke',
	'MySQL version: %s through PHP extension %s' => 'Version de MySQL: %s utilisant l\'extension %s',
	'Logged as: %s' => 'Authentifié en tant que %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'Donnée POST trop grande . Réduire la taille des données ou modifier le "post_max_size" dans la configuration de PHP.',
	'Move up' => 'Déplacer vers le haut',
	'Move down' => 'Déplacer vers le bas',
	'Export' => 'Exporter',
	'skip' => 'sauter',
	'Tables' => 'Tables',
	'Structure' => 'Structure',
	'Data' => 'Donnée',
	'Output' => 'Sortie',
	'open' => 'ouvrir',
	'save' => 'sauvegarder',
	'Format' => 'Formatter',
	'SQL' => 'SQL',
	'CSV' => 'CVS',
	'Functions' => 'Fonctions',
	'Aggregation' => 'Agrégation',
	'Event has been dropped.' => 'L\'évènement a été supprimé.',
	'Event has been altered.' => 'L\'évènement a été modifié.',
	'Event has been created.' => 'L\'évènement a été créé.',
	'Alter event' => 'Modifier un évènement',
	'Create event' => 'Créer un évènement',
	'Start' => 'Démarrer',
	'End' => 'Terminer',
	'Every' => 'Chaque',
	'Status' => 'Status',
	'On completion preserve' => 'Conserver quand complété',
	'Events' => 'Évènement',
	'Schedule' => 'Horaire',
	'At given time' => 'À un moment précis',
	'Save and continue edit' => 'Sauvegarder et continuer l\'édition',
	'original' => 'original',
	'Tables have been truncated.' => 'Les tables ont été tronquées',
	'Tables have been moved.' => 'Les tables ont été déplacées',
	'Tables have been dropped.' => 'Les tables ont été effacées',
	'Tables and views' => 'Tables et vues',
	'Engine' => 'Moteur',
	'Collation' => 'Collation',
	'Data Length' => 'Longeur des données',
	'Index Length' => 'Longeur de l\'index',
	'Data Free' => 'Vide',
	'Rows' => 'Rangés',
	',' => ',',
	'Analyze' => 'Analyser',
	'Optimize' => 'Opitimiser',
	'Check' => 'Vérifier',
	'Repair' => 'Réparer',
	'Truncate' => 'Tronquer',
	'Move to other database' => 'Déplacer dans une autre base de données',
	'Move' => 'Déplacer',
	'%d item(s) have been affected.' => array('%d élément ont été modifié.', '%d éléments ont été modifié.'),
	'whole result' => 'résultat entier',
	'clone' => 'cloner',
	'Clone' => 'Cloner',
);
